@@ -28,8 +28,8 @@
 #' # Choose one R filename to save some R script into it
 #' dlg_save(title = "Save R script to", filters = dlg_filters[c("R", "All"), ])$res
 #' }
-dlg_save <- function(default, title, filters = dlg_filters["All", ], ...,
-gui = .GUI) {
+dlg_save <- function(default = "untitled", title = "Save file as",
+filters = dlg_filters["All", ], ..., gui = .GUI) {
   # Define the S3 method
   # TODO: define default extension!!!
   # A 'save file' dialog box
@@ -40,8 +40,6 @@ gui = .GUI) {
   # for instance: "R or S files (*.R, *.q)"       "*.R;*.q"
   # It could be also an even number of character strings that will be
   # reorganized into a n x 2 matrix.
-  if (missing(default) || !length(default))
-    default <- "untitled"
   if (!gui$startUI("dlg_save", call = match.call(), default = default,
     msg = "Displaying a modal save file dialog box",
     msg.no.ask = "A modal save file dialog box was by-passed"))
@@ -64,11 +62,7 @@ gui = .GUI) {
     if (!file.exists(dir) || !file.info(dir)$isdir)
       default <- file.path(getwd(), basename(default))
   }
-  if (missing(title) || title == "") {
-    title <- "Save file as"
-  } else {
-    title <- as.character(title)[1]
-  }
+  title <- as.character(title)[1]
   # Check that filter is a nx2 character matrix, or try reshape it as such
   if (is.matrix(filters)) {
     if (ncol(filters) != 2 || !is.character(filters))
@@ -83,7 +77,7 @@ gui = .GUI) {
   gui$setUI(args = list(default = default, title = title, filters = filters))
 
   # ... and dispatch to the method
-  UseMethod("dlgSave", gui)
+  UseMethod("dlg_save", gui)
 }
 
 #' @export
@@ -92,7 +86,7 @@ dlgSave <- dlg_save # Backward compatibility
 
 #' @export
 #' @rdname dlg_save
-dlgSave.gui <- function(default, title, filters = dlg_filters["All", ], ...,
+dlg_save.gui <- function(default, title, filters = dlg_filters["All", ], ...,
 gui = .GUI) {
   # Used to break the chain of NextMethod(), searching for a usable method
   # in the current context
@@ -105,7 +99,7 @@ gui = .GUI) {
 
 #' @export
 #' @rdname dlg_save
-dlgSave.textCLI <- function(default, title, filters = dlg_filters["All", ], ...,
+dlg_save.textCLI <- function(default, title, filters = dlg_filters["All", ], ...,
 gui = .GUI) {
   # The pure textual version used as fallback in case no GUI could be used
   gui$setUI(widgets = "textCLI")
@@ -140,7 +134,7 @@ gui = .GUI) {
 #' @inheritParams get_system
 #' @export
 #' @rdname dlg_save
-dlgSave.nativeGUI <- function(default, title, filters = dlg_filters["All", ],
+dlg_save.nativeGUI <- function(default, title, filters = dlg_filters["All", ],
 rstudio = getOption("svDialogs.rstudio", TRUE), ..., gui = .GUI) {
   # The native version of the file save dialog box
   gui$setUI(widgets = "nativeGUI")
@@ -160,7 +154,7 @@ rstudio = getOption("svDialogs.rstudio", TRUE), ..., gui = .GUI) {
 
   # Do we need to further dispatch?
   if (is.null(res)) {
-    NextMethod("dlgSave", gui)
+    NextMethod("dlg_save", gui)
   } else {
     gui$setUI(res = res, status = NULL)
     invisible(gui)
